@@ -1,4 +1,4 @@
-from nonebot import on_command,require
+from nonebot import on_command, on_fullmatch, require
 from nonebot.adapters.onebot.v11 import (
     GROUP,
     GROUP_ADMIN,
@@ -21,6 +21,9 @@ import time
 import asyncio
 import random
 
+import shutil
+import os
+
 from io import BytesIO
 from nonebot_plugin_imageutils import Text2Image
 
@@ -28,12 +31,12 @@ from .utils import is_number, get_message_at
 from .data_source import (
     bot_name,
     russian_manager,
-    single_manager,
     market_manager,
     max_bet_gold,
     race_bet_gold,
     russian_path
     )
+from .data_source import constant_props
 
 from .start import *
 from .race_group import race_group
@@ -54,6 +57,9 @@ driver = get_driver()
 async def events_read():
     global events_list
     events_list = await load_dlcs()
+    market_manager.reset_market_index()
+
+
 
 RaceNew = on_command("赛马创建",aliases = {"创建赛马"}, permission=GROUP, priority=5, block=True)
 RaceJoin = on_command("赛马加入",aliases = {"加入赛马"}, permission=GROUP, priority=5, block=True)
@@ -137,7 +143,6 @@ async def _(bot: Bot, event: GroupMessageEvent, arg: Message = CommandArg()):
     else:
         await RaceJoin.finish(f"请输入你的马儿名字", at_sender=True)
 
-
 @RaceStart.handle()
 async def _(bot: Bot, event: GroupMessageEvent, arg: Message = CommandArg()):
     global race
@@ -196,14 +201,14 @@ async def _(bot: Bot, event: GroupMessageEvent, arg: Message = CommandArg()):
             await RaceStart.send(MessageSegment.image(output))
 
         if text:
-            await asyncio.sleep(0.5 + int(0.1 * len(text)))
+            await asyncio.sleep(0.5 + int(0.06 * len(text)))
         else:
             await asyncio.sleep(0.5)
             
         #全员失败计算
         if race[group].is_die_all():
-            for x in range(len(race[group].player)):
-                uid = race[group].player[x].playeruid
+            for x in race[group].player:
+                uid = x.playeruid
                 if uid > 10:
                     russian_manager._player_data[str(group)][str(uid)]["gold"] += race_bet_gold
             else:
@@ -221,9 +226,9 @@ async def _(bot: Bot, event: GroupMessageEvent, arg: Message = CommandArg()):
                 ) 
             await asyncio.sleep(1)
             gold = int(race_bet_gold * len(race[group].player) / len(winer))
-            for x in range(len(winer)):
-                uid = winer[x][1]
-                winer_list += "> "+ winer[x][0] + "\n"
+            for x in winer:
+                uid = x[1]
+                winer_list += "> "+ x[0] + "\n"
                 if uid > 10:
                     russian_manager._player_data[str(group)][str(uid)]["gold"] += gold
             else:
@@ -241,8 +246,8 @@ async def _(bot: Bot, event: MessageEvent, arg: Message = CommandArg()):
     group = event.group_id
     time_key = math.ceil(time.time() - race[group].time)
     if time_key >= setting_over_time:
-        for x in range(len(race[group].player)):
-            uid = race[group].player[x].playeruid
+        for x in race[group].player:
+            uid = x.playeruid
             if uid > 10:
                 russian_manager._player_data[str(group)][str(uid)]["gold"] += race_bet_gold
         else:
@@ -262,8 +267,8 @@ async def _(bot: Bot, event: GroupMessageEvent, arg: Message = CommandArg()):
 async def _(bot: Bot, event: MessageEvent, arg: Message = CommandArg()):
     global race
     group = event.group_id
-    for x in range(len(race[group].player)):
-        uid = race[group].player[x].playeruid
+    for x in race[group].player:
+        uid = x.playeruid
         if uid > 10:
             russian_manager._player_data[str(group)][str(uid)]["gold"] += race_bet_gold
     else:
@@ -289,12 +294,14 @@ async def _(bot: Bot, event: MessageEvent, arg: Message = CommandArg()):
     await RaceReload.finish(logs)
 
 
+
 sign = on_command("金币签到",aliases={"轮盘签到"}, permission=GROUP, priority=5, block=True)
 
 revolt = on_command("发起重置", aliases={"发起revolt","发动revolt", "revolution", "Revolution"},permission=GROUP, priority=5, block=True)
 revolt_sign = on_command("重置签到",aliases={"revolt签到"},permission=GROUP, priority=5, block=True)
 
 give_gold = on_command("打钱", aliases={"发红包", "赠送金币"},permission=GROUP, priority=5, block=True)
+give_props = on_command("送道具", aliases={"赠送道具"},permission=GROUP, priority=5, block=True)
 
 slot = on_command("（已停用）幸运花色", aliases={"（已停用）抽花色"},permission=GROUP, priority=5, block=True)
 gacha = on_command("十连",aliases={"10连"},rule = to_me(),permission=GROUP, priority=5, block=True)
@@ -318,34 +325,14 @@ my_info = on_command("我的信息", aliases={"我的资料"}, permission=GROUP,
 my_props = on_command("我的道具", aliases={"我的仓库"}, permission=GROUP, priority=5, block=True)
 
 russian_rank = on_command(
-    "胜场排行",
-    aliases={"金币排行", "胜利排行", "败场排行", "失败排行", "欧洲人排行", "慈善家排行"},
+    "金币排行",
+    aliases = {"胜场排行", "胜利排行", "败场排行", "失败排行", "欧洲人排行", "慈善家排行"},
     permission=GROUP,
     priority=5,
     block=True,
     )
 name_list = on_command("查看路灯挂件",aliases={"查看路灯","查看挂件"},permission=GROUP, priority=5, block=True)
 
-intergroup_transfer = on_command("金币转移", permission=GROUP, priority=5, block=True)
-
-Market_public = on_command("市场注册",aliases={"公司注册","注册公司"},rule = to_me(),permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=5, block=True)
-Market_info = on_command("市场信息",aliases={"查看市场"}, priority=5, block=True)
-Market_info_pro = on_command("市场行情",aliases={"市场走势","市场详细信息"}, priority=5, block=True)
-company_info = on_command("公司信息",aliases={"公司资料"}, priority=5, block=True)
-
-Market_buy = on_command("买入",aliases={"购买","购入"},permission=GROUP, priority=5, block=True)
-Market_sell = on_command("卖出",aliases={"出售","上架"},permission=GROUP, priority=5, block=True)
-
-company_buy = on_command("发行购买",aliases={"发行买入"},permission=GROUP, priority=5, block=True)
-company_clear = on_command("官方结算",permission=GROUP, priority=5, block=True)
-
-update_intro = on_command("更新公司简介",aliases={"添加公司简介"},permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=5, block=True)
-update_intro_superuser = on_command("管理员更新公司简介",aliases={"管理员更新公司简介"},permission=SUPERUSER, priority=5, block=True)
-
-reset_sign = on_command("reset_sign", permission=SUPERUSER, priority=5, block=True) # 重置每日签到和每日补贴
-reset_market_index = on_command("reset_market_index", permission=SUPERUSER, priority=5, block=True) # 重置市场指数
-
-
 @sign.handle()
 async def _(event: GroupMessageEvent):
     msg, gold = russian_manager.sign(event)
@@ -388,9 +375,33 @@ async def _(bot: Bot,event: GroupMessageEvent,arg: Message = CommandArg(),):
                         await give_gold.finish("您的账户没有足够的金币", at_sender=True)
                     else:
                         await russian_manager._init_at_player_data(bot,event,at_player_id)
-                        msg = russian_manager.transfer_accounts(player_id,at_player_id,event.group_id,unsettled)
+                        msg = russian_manager.transfer_accounts(event, at_player_id, unsettled)
                         await give_gold.finish(msg)
 
+# 送道具
+
+@give_props.handle()
+async def _(bot: Bot,event: GroupMessageEvent,arg: Message = CommandArg(),):
+    msg = arg.extract_plain_text().strip()
+    if msg:
+        msg = msg.split()
+        at_player_id = get_message_at(event.json())
+        if at_player_id:
+            at_player_id = at_player_id[0]
+            if len(msg) == 1:
+                props = msg[0]
+                count = 1
+            else:
+                props = msg[0]
+                if is_number(msg[1]):
+                    count = abs(int(msg[1])) or 1
+                else:
+                    count = 1
+            russian_manager._init_player_data(event)
+            await russian_manager._init_at_player_data(bot,event,at_player_id)
+            msg = russian_manager.give_props(event, at_player_id, props, count)
+            await give_props.finish(msg, at_sender=True)
+
 # 状态处理
 
 @accept.handle()
@@ -449,8 +460,8 @@ async def _(
         msg = msg.split()
         if len(msg) == 1:
             msg = msg[0]
-            if is_number(msg):
-                if 0 < int(msg) < 7:
+            if is_number(msg) and 0 < int(msg):
+                if int(msg) < 7:
                     bullet_num = int(msg)
                 else:
                     money = int(msg)
@@ -459,7 +470,7 @@ async def _(
             msg[1] = msg[1].strip()         
             if is_number(msg[0]) and 0 < int(msg[0]) < 7:
                 bullet_num = int(msg[0])
-            if is_number(msg[1]):
+            if is_number(msg[1]) and 0 < int(msg[1]):
                 money = int(msg[1])
 
         state["bullet_num"] = bullet_num
@@ -622,8 +633,7 @@ async def _(bot: Bot, event: GroupMessageEvent, arg: Message = CommandArg()):
     card = arg.extract_plain_text().strip()
     await russian_manager.poker_play(bot, event, card)
 
-# 单人游戏
-
+# 幸运花色
 @slot.handle()
 async def _(bot: Bot, event: GroupMessageEvent,arg: Message = CommandArg()):
     gold = 50
@@ -633,13 +643,14 @@ async def _(bot: Bot, event: GroupMessageEvent,arg: Message = CommandArg()):
             if 0 < tmp <= int(max_bet_gold/2):
                 gold = abs(int(str(arg)))
 
-    msg = single_manager.slot(event,gold)
-    await slot.send(MessageSegment.at(event.user_id) + msg)
+    msg = russian_manager.slot(event,gold)
+    await slot.finish(msg, at_sender=True)
 
+# 十连抽卡
 @gacha.handle()
 async def _(bot: Bot, event: GroupMessageEvent,arg: Message = CommandArg()):
-    msg = single_manager.gacha(event)
-    await gacha.send(msg,at_sender=True,)
+    msg = russian_manager.gacha(event)
+    await gacha.finish(msg, at_sender=True)
 
 # 我的
 
@@ -650,7 +661,7 @@ async def _(event: GroupMessageEvent):
     props_info = '\n'
     for x in props.keys():
         if props[x] != 0:
-            if x == "钻石":
+            if x in constant_props:
                 props_info += f'『{x}』 {props[x]}个\n'
             else:
                 props_info += f'『{x}』 {props[x]}天\n'
@@ -658,55 +669,19 @@ async def _(event: GroupMessageEvent):
     props_info = props_info[:-1]
     if not props_info:
         props_info = "你的仓库空空如也..."
-    await my_props.send(props_info,at_sender=True)
+    await my_props.finish(props_info,at_sender=True)
 
 @my_gold.handle()
 async def _(event: GroupMessageEvent):
     gold = russian_manager.get_user_data(event)["gold"]
-    await my_gold.send(f"你还有 {gold} 枚金币", at_sender=True)
+    await my_gold.finish(f"你还有 {gold} 枚金币", at_sender=True)
 
 @my_info.handle()
 async def _(event: GroupMessageEvent):
-    nickname = russian_manager.get_user_data(event)["nickname"]
-    gold = russian_manager.get_user_data(event)["gold"]
-    make_gold = russian_manager.get_user_data(event)["make_gold"]
-    lose_gold = russian_manager.get_user_data(event)["lose_gold"]
-    is_sign = russian_manager.get_user_data(event)["is_sign"]
-    security = russian_manager.get_user_data(event)["security"]
-    win_count = russian_manager.get_user_data(event)["win_count"]
-    lose_count = russian_manager.get_user_data(event)["lose_count"]
-    stock = russian_manager.get_user_data(event)["stock"]
-    my_stock = []
-    stock_info = ""
-    for x in stock.keys():
-        if x != "value" and  stock[x] != 0 :
-            my_stock.append([x,round(market_manager._market_data[x]["gold"] * stock[x] / 20000,2)])
-    else:
-        my_stock.sort(key = lambda x:x[1],reverse = True)
-        for i in range(len(my_stock)):
-            stock_info += f'【{my_stock[i][0]}】\n持有：{stock[my_stock[i][0]]} 株\n价值：{my_stock[i][1]} 金币\n'
-
-    info=(
-        f'【{nickname}】\n'
-        "——————————————\n"+
-        ("" if russian_manager.Achieve_list(russian_manager.get_user_data(event)) == "" 
-            else russian_manager.Achieve_list(russian_manager.get_user_data(event)) + "——————————————\n") +
-        f'金币：{gold}\n'
-        f'持有价值：{round(stock["value"],2)}\n'
-        f'赚取金币：{make_gold}\n'
-        f'输掉金币：{lose_gold}\n'
-        "——————————————\n"
-        f'胜场:败场：{win_count}:{lose_count}\n'
-        f'胜率：{str((win_count/(win_count + lose_count) if win_count + lose_count > 0 else 0 ) * 100 )[:5]}%\n'
-        "——————————————\n"
-        f'今日签到：{"已签到"if is_sign else "未签到"}\n'
-        f'今日补贴：还剩 {3 - security} 次\n'
-        "——————————————\n" +
-        stock_info
-        )
+    info = russian_manager.my_info(event)
     output = BytesIO()
     Text2Image.from_text(info[:-1],50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
-    await my_gold.send(MessageSegment.image(output))
+    await my_info.finish(MessageSegment.image(output))
 
 # 查看排行榜
 @russian_rank.handle()
@@ -718,6 +693,7 @@ async def _(event: GroupMessageEvent, state: T_State = State()):
         await russian_rank.finish(MessageSegment.image(output))
     else:
         await russian_rank.finish()
+
 # 查看路灯挂件
 @name_list.handle()
 async def _(event: GroupMessageEvent):
@@ -737,7 +713,8 @@ async def _(event: GroupMessageEvent):
             rst += f"{name}：达成{_max}次\n"
             all_user_data.remove(_max)
             all_user.remove(_max_id)
-        rst = rst[:-1]
+        else:
+            rst = rst[:-1]
         if rst:
             await name_list.finish("☆ ☆ 路灯挂件榜 ☆ ☆\n" + rst)
         else:
@@ -745,6 +722,203 @@ async def _(event: GroupMessageEvent):
     else:
         await name_list.finish()
 
+
+
+Market_public = on_command("市场注册",aliases={"公司注册","注册公司"},rule = to_me(),permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=5, block=True)
+
+company_buy = on_command("发行购买",aliases={"发行买入"},permission=GROUP, priority=5, block=True)
+company_clear = on_command("官方结算",permission=GROUP, priority=5, block=True)
+
+Market_buy = on_command("买入",aliases={"购买","购入"},permission=GROUP, priority=5, block=True)
+Market_sell = on_command("卖出",aliases={"出售","上架"},permission=GROUP, priority=5, block=True)
+
+Market_info = on_command("市场信息",aliases={"查看市场"}, priority=5, block=True)
+Market_info_pro = on_command("市场行情",aliases={"市场走势","市场详细信息"}, priority=5, block=True)
+
+company_info = on_command("公司信息",aliases={"公司资料"}, priority=5, block=True)
+
+update_intro = on_command("更新公司简介",aliases={"添加公司简介"},permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=5, block=True)
+update_intro_superuser = on_command("管理员更新公司简介",aliases={"管理员更新公司简介"},permission=SUPERUSER, priority=5, block=True)
+
+intergroup_transfer = on_command("金币转移", permission=GROUP, priority=5, block=True)
+
+# 公司上市
+@Market_public.handle()
+async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
+    msg = arg.extract_plain_text().strip()
+    if msg:
+        msg = msg.split()
+        if len(msg) == 1:
+            msg = msg[0]
+            msg = market_manager.Market_public(event,msg)
+            await Market_public.finish(msg)
+        else:
+            await Market_public.finish(f"错误：公司名称格式错误\n{str(msg)}")
+    else:
+        await Market_public.finish("错误：未设置公司名称")
+
+# 发行购买
+@company_buy.handle()
+async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
+    msg = arg.extract_plain_text().strip()
+    if msg:
+        msg = msg.split()
+        if len(msg) == 2:
+            company_name = msg[0]
+            stock = abs(int(msg[1])) if is_number(msg[1]) else 100
+            msg = market_manager.company_buy(event,company_name,stock)
+            try:
+                await company_buy.send(msg)
+            except:
+                output = BytesIO()
+                Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
+                await company_buy.send(MessageSegment.image(output))
+            finally:
+                await company_buy.finish()
+
+# 债务清算
+@company_clear.handle()
+async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
+    msg = arg.extract_plain_text().strip()
+    if msg:
+        msg = msg.split()
+        if len(msg) == 2:
+            company_name = msg[0]            
+            stock = abs(int(msg[1])) if is_number(msg[1]) else 100
+            msg = market_manager.company_clear(event,company_name,stock)
+            try:
+                await company_clear.send(msg)
+            except:
+                output = BytesIO()
+                Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
+                await company_clear.send(MessageSegment.image(output))
+            finally:
+                await company_clear.finish()
+
+# 市场买入
+@Market_buy.handle()
+async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
+    msg = arg.extract_plain_text().strip()
+    if msg:
+        msg = msg.split()
+        if len(msg) == 2:
+            company_name = msg[0]            
+            stock = abs(int(msg[1])) if is_number(msg[1]) else 100
+            msg = market_manager.Market_buy(event,company_name,stock)
+            try:
+                await Market_buy.send(msg)
+            except:
+                output = BytesIO()
+                Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
+                await Market_buy.send(MessageSegment.image(output))
+            finally:
+                await Market_buy.finish()
+
+# 市场卖出
+@Market_sell.handle()
+async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
+    msg = arg.extract_plain_text().strip()
+    if msg:
+        msg = msg.split()
+        if len(msg) == 3:
+            company_name = msg[0]
+            if is_number(msg[1]):
+                quote = abs(float(msg[1]))
+                stock = abs(int(msg[2])) if is_number(msg[2]) else 100
+                msg = market_manager.Market_sell(event,company_name,quote,stock)
+                try:
+                    await Market_sell.send(msg)
+                except:
+                    output = BytesIO()
+                    Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
+                    await Market_sell.send(MessageSegment.image(output))
+                finally:
+                    await Market_sell.finish()
+
+# 市场信息
+@Market_info.handle()
+async def _(bot:Bot, event: MessageEvent,arg: Message = CommandArg()):
+    company_name = arg.extract_plain_text().strip()
+    if company_name:
+        company_name = company_name.split()
+        if len(company_name) == 1:
+            company_name = company_name[0]
+        else:
+            company_name == ""
+    else:
+        company_name == ""
+    msg = market_manager.Market_info(event,company_name)
+    if type(msg) == list:
+        await bot.send_group_forward_msg(group_id=event.group_id, messages = msg)
+        await Market_info.finish()
+    else:
+        await Market_info.finish(msg)
+
+# 市场走势
+@Market_info_pro.handle()
+async def _(bot:Bot, event: MessageEvent):
+    msg = market_manager.Market_info_pro(event)
+    if type(msg) == list:
+        if isinstance(event, GroupMessageEvent):
+            await bot.send_group_forward_msg(group_id = event.group_id, messages = msg)
+        else:
+            await bot.send_private_forward_msg(user_id = event.user_id, messages = msg)
+        await Market_info_pro.finish()
+    else:
+        await Market_info_pro.finish(msg)
+
+# 公司信息
+@company_info.handle()
+async def _(event: MessageEvent,arg: Message = CommandArg()):
+    company_name = arg.extract_plain_text().strip()
+    if company_name:
+        company_name = company_name.split()
+        company_name = company_name[0]
+        msg = market_manager.company_info(company_name)
+        if msg:
+            output = BytesIO()
+            Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
+            await company_info.finish(MessageSegment.image(output))
+        else:
+            await company_info.finish(f"【{company_name}】未注册")
+# 更新公司简介
+@update_intro.handle()
+async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
+    intro = arg.extract_plain_text().strip()
+    group_id = str(event.group_id)
+    if intro:
+        if group_id in market_manager._market_data.keys():
+            company_name = market_manager._market_data[group_id]["company_name"]
+            market_manager.update_intro(company_name,intro)
+            await update_intro.finish("简介更新完成...")
+        else:
+            await update_intro.finish(f"群号：{group_id}未注册")
+    else:
+        await update_intro.finish()
+
+# 管理员更新简介
+@update_intro_superuser.handle()
+async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
+    msg = arg.extract_plain_text().strip()
+    if msg:
+        msg = msg.split(" ",1)
+        market_manager.update_intro(msg[0],msg[1])
+        await update_intro_superuser.finish("简介更新完成...")
+
+# 跨群转移金币到自己的账户
+@intergroup_transfer.handle()
+async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
+    msg = arg.extract_plain_text().strip().split()
+    if len(msg) == 2 and is_number(msg[1]):
+        company_name = msg[0]
+        gold = msg[1]
+        msg = market_manager.intergroup_transfer(event,company_name,gold)
+        await intergroup_transfer.finish(msg, at_sender=True)
+
+
+
+reset_sign = on_command("reset_sign", permission=SUPERUSER, priority=5, block=True) # 重置每日签到和每日补贴
+
 # 刷新每日签到和每日补贴
 @reset_sign.handle()
 async def _():
@@ -774,196 +948,26 @@ async def _():
     logger.info("幸运花色已重置...")
     russian_manager.save()
 '''
-
-# 公司上市
-@Market_public.handle()
-async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
-    msg = arg.extract_plain_text().strip()
-    if msg:
-        msg = msg.split()
-        if len(msg) == 1:
-            msg = msg[0]
-            msg = market_manager.Market_public(event,msg)
-            await Market_public.finish(msg)
-        else:
-            await Market_public.finish(f"错误：公司名称格式错误\n{str(msg)}")
-    else:
-        await Market_public.finish("错误：未设置公司名称")
-
-# 发行购买
-@company_buy.handle()
-async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
-    msg = arg.extract_plain_text().strip()
-    if msg:
-        msg = msg.split()
-        if len(msg) == 2:
-            company_name = msg[0]
-            stock = abs(int(msg[1])) if is_number(msg[1]) else 100
-            msg = market_manager.company_buy(event,company_name,stock)
-            output = BytesIO()
-            Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
-            await company_buy.finish(MessageSegment.image(output))
-
-# 债务清算
-@company_clear.handle()
-async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
-    msg = arg.extract_plain_text().strip()
-    if msg:
-        msg = msg.split()
-        if len(msg) == 2:
-            company_name = msg[0]            
-            stock = abs(int(msg[1])) if is_number(msg[1]) else 100
-            msg = market_manager.company_clear(event,company_name,stock)
-            output = BytesIO()
-            Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
-            await company_clear.finish(MessageSegment.image(output))
-
-# 市场买入
-@Market_buy.handle()
-async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
-    msg = arg.extract_plain_text().strip()
-    if msg:
-        msg = msg.split()
-        if len(msg) == 2:
-            company_name = msg[0]            
-            stock = abs(int(msg[1])) if is_number(msg[1]) else 100
-            msg = market_manager.Market_buy(event,company_name,stock)
-            output = BytesIO()
-            Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
-            await Market_buy.finish(MessageSegment.image(output))
-
-# 市场卖出
-@Market_sell.handle()
-async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
-    msg = arg.extract_plain_text().strip()
-    if msg:
-        msg = msg.split()
-        if len(msg) == 3:
-            company_name = msg[0]
-            if is_number(msg[1]):
-                quote = abs(float(msg[1]))
-                stock = abs(int(msg[2])) if is_number(msg[2]) else 100
-                msg = market_manager.Market_sell(event,company_name,quote,stock)
-                output = BytesIO()
-                Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
-                await Market_sell.finish(MessageSegment.image(output))
-
-# 市场信息
-@Market_info.handle()
-async def _(bot:Bot, event: MessageEvent,arg: Message = CommandArg()):
-    company_name = arg.extract_plain_text().strip()
-    if company_name:
-        company_name = company_name.split()
-        if len(company_name) == 1:
-            company_name = company_name[0]
-        else:
-            company_name == ""
-    else:
-        company_name == ""
-    msg = market_manager.Market_info(event,company_name)
-    if type(msg) == list:
-        await bot.send_group_forward_msg(group_id=event.group_id, messages = msg)
-        await Market_info.finish()
-    else:
-        await Market_info.finish(msg)
-
-# 市场走势
-@Market_info_pro.handle()
-async def _(bot:Bot, event: MessageEvent):
-    msg = await market_manager.Market_info_pro(event)
-    if type(msg) == list:
-        if isinstance(event, GroupMessageEvent):
-            await bot.send_group_forward_msg(group_id = event.group_id, messages = msg)
-        else:
-            await bot.send_private_forward_msg(user_id = event.user_id, messages = msg)
-        await Market_info_pro.finish()
-    else:
-        await Market_info_pro.finish(msg)
-
-# 公司信息
-@company_info.handle()
-async def _(event: MessageEvent,arg: Message = CommandArg()):
-    company_name = arg.extract_plain_text().strip()
-    if company_name:
-        company_name = company_name.split()
-        if len(company_name) == 1:
-            company_name = company_name[0]
-            msg = market_manager.company_info(company_name)
-            output = BytesIO()
-            Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
-            await company_info.finish(MessageSegment.image(output))
-
-# 管理员更新简介
-@update_intro_superuser.handle()
-async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
-    msg = arg.extract_plain_text().strip()
-    if msg:
-        msg = msg.split(" ",1)
-        market_manager.update_intro(msg[0],msg[1])
-        await update_intro_superuser.finish("简介更新完成...")
-
-# 更新公司简介
-@update_intro.handle()
-async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
-    intro = arg.extract_plain_text().strip()
-    group_id = str(event.group_id)
-    if intro:
-        if group_id in market_manager._market_data.keys():
-            company_name = market_manager._market_data[group_id]["company_name"]
-            market_manager.update_intro(company_name,intro)
-            await update_intro.finish("简介更新完成...")
-        else:
-            await update_intro.finish(f"群号：{group_id}未注册")
-    else:
-        await update_intro.finish()
-
-# 跨群转移金币到自己的账户
-
-@intergroup_transfer.handle()
-async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
-    msg = arg.extract_plain_text().strip().split()
-    if len(msg) == 2 and is_number(msg[1]):
-        company_name = msg[0]
-        gold = msg[1]
-        msg = market_manager.intergroup_transfer(event,company_name,gold)
-        await intergroup_transfer.finish(msg, at_sender=True)
-        
+     
 # 刷新道具时间
 @scheduler.scheduled_job("cron", hour = 4, minute = 0)
 async def _():
     for group_id in russian_manager._player_data.keys():
         for user_id in russian_manager._player_data[group_id].keys():
             for props in russian_manager._player_data[group_id][user_id]["props"].keys():
-                if russian_manager._player_data[group_id][user_id]["props"][props] > 0 and props!="钻石":
+                if russian_manager._player_data[group_id][user_id]["props"][props] > 0 and props not in constant_props:
                     russian_manager._player_data[group_id][user_id]["props"][props] -= 1
     else:
         logger.info("道具时间已刷新...")
         russian_manager.save()
 
-# 市场指数更新（手动）
-@reset_market_index.handle()
-async def _():
-    msg = ""
-    for group_id in russian_manager._player_data.keys():
-        if group_id in market_manager._market_data.keys():
-            company_name = market_manager._market_data[group_id]["company_name"]
-            market_manager.market_index[company_name] = random.uniform(-0.5, 0.1)
-            logger.info(f'【{company_name}】市场指数更新为 {market_manager.market_index.get(company_name,0)}')
-            msg += f'【{company_name}】市场指数更新为 {round(market_manager.market_index.get(company_name,0),4)}\n'
-    else:
-        await reset_market_index.finish(msg[:-1])
-
 # 市场指数更新
-@scheduler.scheduled_job("cron", hour = "0,6,12,18")
+@scheduler.scheduled_job("cron", hour = "0,3,6,9,12,15,18,21")
 async def _():
-    for group_id in russian_manager._player_data.keys():
-        if group_id in market_manager._market_data.keys():
-            company_name = market_manager._market_data[group_id]["company_name"]
-            market_manager.market_index[company_name] = random.uniform(-0.5, 0.1)
-            logger.info(f'【{company_name}】市场指数更新为 {market_manager.market_index.get(company_name,0)}')
+    market_manager.reset_market_index()
 
 # 股市更新
-@scheduler.scheduled_job("cron",minute = "0,5,10,15,20,25,30,35,40,45,50,55")
+@scheduler.scheduled_job("cron", minute = "0,5,10,15,20,25,30,35,40,45,50,55")
 async def _():
     for group_id in russian_manager._player_data.keys():
         for user_id in russian_manager._player_data[group_id].keys():
@@ -980,25 +984,18 @@ async def _():
 
 # 数据备份
 
-import shutil
-import os
-from .data_source import russian_path
-
 @scheduler.scheduled_job("cron",hour = "4,10,16,22")
 async def _():
     now = time.strftime('%Y-%m-%d-%H', time.localtime(time.time()))
     path =f"{russian_path}/data/russian"
-    try:
-        if not os.path.exists(f"{path}/backup"):
-            os.makedirs(f"{path}/backup")
-        if os.path.isfile(f"{path}/market_data.json"):
-            shutil.copy(f"{path}/market_data.json",f"{path}/backup/market_data {now}.json")
-            logger.info(f'market_data.json备份成功！')
-        if os.path.isfile(f"{path}/russian_data.json"):
-            shutil.copy(f"{path}/russian_data.json",f"{path}/backup/russian_data {now}.json")
-            logger.info(f'russian_data.json备份成功！')
-        if os.path.isfile(f"{path}/Stock_Exchange.json"):
-            shutil.copy(f"{path}/Stock_Exchange.json",f"{path}/backup/Stock_Exchange {now}.json")
-            logger.info(f'Stock_Exchange.json备份成功！')
-    except:
-        logger.info(f'数据备份失败...')
\ No newline at end of file
+    if not os.path.exists(f"{path}/backup"):
+        os.makedirs(f"{path}/backup")
+    if os.path.isfile(f"{path}/market_data.json"):
+        shutil.copy(f"{path}/market_data.json",f"{path}/backup/market_data {now}.json")
+        logger.info(f'market_data.json备份成功！')
+    if os.path.isfile(f"{path}/russian_data.json"):
+        shutil.copy(f"{path}/russian_data.json",f"{path}/backup/russian_data {now}.json")
+        logger.info(f'russian_data.json备份成功！')
+    if os.path.isfile(f"{path}/Stock_Exchange.json"):
+        shutil.copy(f"{path}/Stock_Exchange.json",f"{path}/backup/Stock_Exchange {now}.json")
+        logger.info(f'Stock_Exchange.json备份成功！')
\ No newline at end of file
