@@ -45,6 +45,9 @@ russian_config = Config.parse_obj(nonebot.get_driver().config.dict())
 max_bet_gold = russian_config.max_bet_gold
 race_bet_gold = russian_config.race_bet_gold
 
+# 定义永久道具
+constant_props = ("钻石","路灯挂件标记")
+
 async def rank(player_data: dict, group_id: int, type_: str) -> str:
     """
     排行榜数据统计
@@ -674,23 +677,23 @@ class GameManager:
         '''
         card_msg = "技能牌为"
         skill_msg = "\n"
-        for i in range(len(st["hand"])):
-            card_msg += f'【{suit_name_dict[st["hand"][i][0]]} {point_dict[st["hand"][i][1]]}】'
-            if st["hand"][i][0] == 1:
-                st["DEF"] += st["hand"][i][1]
-                skill_msg += f'♤防御力强化了 {st["hand"][i][1]}\n'
-            elif st["hand"][i][0] == 2:
-                st["HP"] += st["hand"][i][1]
-                skill_msg += f'♡生命值增加了 {st["hand"][i][1]}\n'
-            elif st["hand"][i][0] == 3:
-                st["SP"] += 2 * st["hand"][i][1]
-                skill_msg += f'♧技能点增加了 {st["hand"][i][1]}\n'
-            elif st["hand"][i][0] == 4:
-                st["ATK"] += st["hand"][i][1]
-                skill_msg += f'♢发动了攻击 {st["hand"][i][1]}\n'
+        for card in st["hand"]:
+            card_msg += f'【{suit_name_dict[card[0]]} {point_dict[card[1]]}】'
+            if card[0] == 1:
+                st["DEF"] += card[1]
+                skill_msg += f'♤防御力强化了 {card[1]}\n'
+            elif card[0] == 2:
+                st["HP"] += card[1]
+                skill_msg += f'♡生命值增加了 {card[1]}\n'
+            elif card[0] == 3:
+                st["SP"] += 2 * card[1]
+                skill_msg += f'♧技能点增加了 {card[1]}\n'
+            elif card[0] == 4:
+                st["ATK"] += card[1]
+                skill_msg += f'♢发动了攻击 {card[1]}\n'
             else:
                 msg = "出现未知错误"
-            st["SP"] = 0 if st["SP"] - st["hand"][i][1] < 0 else st["SP"] - st["hand"][i][1]
+            st["SP"] = 0 if st["SP"] - card[1] <= 0 else st["SP"] - card[1]
         else:
             msg = card_msg + skill_msg[:-1]
             return msg
@@ -967,15 +970,15 @@ class GameManager:
         :param msg: 排行榜类型
         :param group_id: 群号
         """
-        if msg in ["金币排行"]:
+        if "金币排行" in msg:
             return await rank(self._player_data, group_id, "gold_rank")
-        if msg in ["胜场排行", "胜利排行"]:
+        if "胜场排行" in msg or "胜利排行" in msg:
             return await rank(self._player_data, group_id, "win_rank")
-        if msg in ["败场排行", "失败排行"]:
+        if "败场排行" in msg or "失败排行" in msg:
             return await rank(self._player_data, group_id, "lose_rank")
-        if msg == "欧洲人排行":
+        if "欧洲人排行" in msg:
             return await rank(self._player_data, group_id, "make_gold")
-        if msg == "慈善家排行":
+        if "慈善家排行" in msg:
             return await rank(self._player_data, group_id, "lose_gold")
 
     def check_game_is_start(self, group_id: int) -> bool:
@@ -1241,14 +1244,11 @@ class GameManager:
         all_user = list(player_data[group_id].keys())
         sum = 0
         if all_user:
-            all_user_gold = [player_data[group_id][x]["gold"] for x in all_user]
-            all_user_value = [player_data[group_id][x]["stock"]["value"] for x in all_user]
+            all_user_gold = [player_data[group_id][i]["gold"] + player_data[group_id][i]["stock"]["value"] for i in all_user]
             for _ in range(len(all_user) if len(all_user) < number else number):
                 _max_gold = max(all_user_gold)
-                _max_value = max(all_user_value)
-                sum = sum + int(_max_gold) + int(_max_value)
+                sum = sum + int(_max_gold)
                 all_user_gold.remove(_max_gold)
-                all_user_value.remove(_max_value)
             return sum
         else:
             return -1
@@ -1261,7 +1261,7 @@ class GameManager:
         player_data = self._player_data
         group_id = str(group_id)
         all_user = list(player_data[group_id].keys())
-        all_user_data = [player_data[group_id][x]["gold"] for x in all_user]
+        all_user_data = [player_data[group_id][i]["gold"] + player_data[group_id][i]["stock"]["value"] for i in all_user]
         first = max(all_user_data)
         first_id = all_user[all_user_data.index(first)]
         first_name = player_data[group_id][first_id]["nickname"]
@@ -1272,15 +1272,23 @@ class GameManager:
                     _max = max(all_user_data)
                     _max_id = all_user[all_user_data.index(_max)]
                     player_data[group_id][_max_id]["gold"] = int(_max*0.2)
+                    for company_name in player_data[group_id][_max_id]["stock"].keys():
+                        if company_name == "value":
+                            continue
+                        else:
+                            stock = int(player_data[group_id][_max_id]["stock"][company_name] * 0.8)
+                            player_data[group_id][_max_id]["stock"][company_name] -= stock
+                            market_manager._market_data[company_name]["stock"] += stock
                     all_user_data.remove(_max)
                     all_user.remove(_max_id)
                 for user_id in player_data[group_id].keys():
                     player_data[group_id][user_id]["revolution"] = False
                 player_data[group_id][first_id]["Achieve_revolution"] += 1
                 self.save()
+                market_manager.market_data_save()
                 return f"重置成功\n恭喜{first_name}进入路灯挂件榜~☆！"
             else:
-                return f"{first_name}的金币需要达到{8000 if sum - first < 8000 else sum - first}才可以发起重置。"
+                return f"{first_name}的金币需要达到{round(8000 if sum - first < 8000 else sum - first, 2)}才可以发起重置。"
         else:
             return None
 
@@ -1322,44 +1330,85 @@ class GameManager:
 
     def transfer_accounts(
         self,
-        player_id: int,
+        event: GroupMessageEvent,
         at_player_id: int,
-        group_id: int,
         unsettled: int,
-        ):
+        ) -> str:
         """
         转账数据处理保存
-        :param player_id: 转出账户玩家id
+        :param event: event
         :param at_player_id: 转入账户玩家id
-        :param group_id: 群聊
         :param unsettled: 转账金额
         """
-        player_id=str(player_id)
-        at_player_id=str(at_player_id)
-        group_id=str(group_id)
-
-        flag = self._player_data[group_id][player_id]["props"].get("钻石会员卡",0)
+        user_id = str(event.user_id)
+        group_id = str(event.group_id)
+        at_player_id = str(at_player_id)
+        flag = self._player_data[group_id][user_id]["props"].get("钻石会员卡",0)
         if flag > 0:
             fee = 0
         else:
             fee = int(unsettled * 0.02)
 
-        self._player_data[group_id][player_id]["gold"] -= unsettled
+        self._player_data[group_id][user_id]["gold"] -= unsettled
         self._player_data[group_id][at_player_id]["gold"] += unsettled - fee
         self.save()
         return (
-            f"{self._player_data[group_id][player_id]['nickname']} 向 {self._player_data[group_id][at_player_id]['nickname']} 转账{unsettled}金币\n"+
+            f"{self._player_data[group_id][user_id]['nickname']} 向 {self._player_data[group_id][at_player_id]['nickname']} 转账{unsettled}金币\n"+
             ("『钻石会员卡』免手续费" if flag > 0 else f"扣除2%手续费：{fee}，实际到账金额{unsettled - fee}")
             )
 
+    def give_props(
+        self,
+        event: GroupMessageEvent,
+        at_player_id: int,
+        props: str,
+        count: int,
+        ) -> str:
+        """
+        送道具
+        :param event: event
+        :param at_player_id: 接收道具玩家id
+        :param props: 道具名
+        :param count: 道具数量
+        """
+        user_id = str(event.user_id)
+        group_id = str(event.group_id)
+        at_player_id = str(at_player_id)
+
+        user_data = self._player_data[group_id][user_id]
+        at_user_data = self._player_data[group_id][at_player_id]
+        if props == "路灯挂件标记":
+            if user_data["Achieve_revolution"] + user_data["props"].get(props,0) < count:
+                return "数量不足"
+            else:
+                user_data["props"].setdefault(props,0)
+                user_data["props"][props] -= count
+                at_user_data["props"].setdefault(props,0)
+                at_user_data["props"][props] += count
+                self.save()
+                return f"{count} 个 {props} 已送出"
+        else:
+            if user_data["props"].get(props,0) < count:
+                return "数量不足"
+            else:
+                user_data["props"][props] -= count
+                at_user_data["props"].setdefault(props,0)
+                at_user_data["props"][props] += count
+                self.save()
+                return f"{count} 个 {props} 已送出"
+
     def Achieve_list(self,user_data):
+        """
+        送道具
+        :param user_data: russian_manager.get_user_data(event)
+        """
         rank = ""
         count = user_data["props"].get("四叶草标记",0)
-        if count >0:
-            rank += "𝐿𝒰𝒞𝒦𝒴 ✤ 𝒞𝐿𝒪𝒱𝐸𝑅\n"
-        count = user_data["Achieve_revolution"]
         if count > 0:
-            if count <=5:
+            rank += "𝐿𝒰𝒞𝒦𝒴 ✤ 𝒞𝐿𝒪𝒱𝐸𝑅\n"
+        count = user_data["Achieve_revolution"] + user_data["props"].get("路灯挂件标记",0)
+        if count > 0:
+            if count < 5:
                 rank += f"{count*'☆ '}路灯挂件{count*' ☆'}\n"
             else: 
                 rank += f"❀ 路灯挂件 Lv.{count} ❀\n"
@@ -1374,15 +1423,53 @@ class GameManager:
             rank += f"◆◇ 连败 Lv.{count-1} ◆◇\n"
         return rank
 
+    def my_info(self, event: GroupMessageEvent) -> str:
+        """
+        资料卡
+        :param event: event
+        """
+        user_data = self.get_user_data(event)
+        nickname = user_data["nickname"]
+        gold = user_data["gold"]
+        make_gold = user_data["make_gold"]
+        lose_gold = user_data["lose_gold"]
+        is_sign = user_data["is_sign"]
+        security = user_data["security"]
+        win_count = user_data["win_count"]
+        lose_count = user_data["lose_count"]
+        stock = user_data["stock"]
+        stock["value"] = market_manager.value_update(str(event.group_id),str(event.user_id))
+        my_stock = []
+        stock_info = ""
+        for x in stock.keys():
+            if x == "value" or  stock[x] == 0 :
+                continue
+            else:
+                my_stock.append([x,round(market_manager._market_data[x]["float_gold"] * stock[x] / 20000,2)])
+        else:
+            my_stock.sort(key = lambda x:x[1],reverse = True)
+            for x in my_stock:
+                stock_info += f'【{x[0]}】\n持有：{stock[x[0]]} 株\n价值：{x[1]} 金币\n'
 
+        info = (
+            f'【{nickname}】\n'
+            "——————————————\n"
+            + ("" if self.Achieve_list(user_data) == "" else self.Achieve_list(user_data) + "——————————————\n") +
+            f'金币：{gold}\n'
+            f'持有价值：{round(stock["value"],2)}\n'
+            f'赚取金币：{make_gold}\n'
+            f'输掉金币：{lose_gold}\n'
+            "——————————————\n"
+            f'胜场:败场：{win_count}:{lose_count}\n'
+            f'胜率：{str((win_count/(win_count + lose_count) if win_count + lose_count > 0 else 0 ) * 100 )[:5]}%\n'
+            "——————————————\n"
+            f'今日签到：{"已签到"if is_sign else "未签到"}\n'
+            f'今日补贴：还剩 {3 - security} 次\n'
+            "——————————————\n" +
+            stock_info
+            )
+        return info
 
-russian_manager = GameManager()
-
-
-
-class SingleManager:
-    def __init__(self):
-        self._current_player = {}
     def slot(self, event: GroupMessageEvent,gold:int):
         """
         抽花色
@@ -1392,12 +1479,12 @@ class SingleManager:
         group_id = str(event.group_id)
         user_id = str(event.user_id)
         
-        if gold > russian_manager.get_user_data(event)["gold"]:
-            return f'你没有足够的金币，你的金币：{russian_manager._player_data[group_id][user_id]["gold"]}。'
-        if russian_manager._player_data[group_id][user_id]["slot"] > 2:
+        if gold > self.get_user_data(event)["gold"]:
+            return f'你没有足够的金币，你的金币：{self._player_data[group_id][user_id]["gold"]}。'
+        if self._player_data[group_id][user_id]["slot"] > 2:
             return '你的本轮次数已用光。'
 
-        russian_manager._player_data[group_id][user_id]["slot"] += 1
+        self._player_data[group_id][user_id]["slot"] += 1
         suit_dict = {
             1:"♤",
             2:"♡",
@@ -1411,8 +1498,8 @@ class SingleManager:
         lst=[x,y,z]
         lst0=list(set(lst))
         if len(lst0)==1:
-            russian_manager._player_data[group_id][user_id]["gold"] += gold *7
-            russian_manager._player_data[group_id][user_id]["make_gold"] += gold *7
+            self._player_data[group_id][user_id]["gold"] += gold *7
+            self._player_data[group_id][user_id]["make_gold"] += gold *7
             msg =(
                 f"你抽到的花色为：\n"+
                 suit+
@@ -1425,15 +1512,15 @@ class SingleManager:
                 f"\n祝你好运~"
                 )
         else:
-            russian_manager._player_data[group_id][user_id]["gold"] -= gold
-            russian_manager._player_data[group_id][user_id]["lose_gold"] += gold
+            self._player_data[group_id][user_id]["gold"] -= gold
+            self._player_data[group_id][user_id]["lose_gold"] += gold
             msg =(
                 f"你抽到的花色为：\n"+
                 suit+
                 f"\n你失去了{gold}金币 ，祝你好运~"
                 )
 
-        russian_manager.save()
+        self.save()
         return msg
 
     def gacha(self, event: GroupMessageEvent):
@@ -1444,34 +1531,34 @@ class SingleManager:
         group_id = str(event.group_id)
         user_id = str(event.user_id)
         
-        if russian_manager.get_user_data(event)["gold"] < gacha_gold:
-            return f'10连抽卡需要{gacha_gold}金币，你的金币：{russian_manager._player_data[group_id][user_id]["gold"]}。'
+        if self.get_user_data(event)["gold"] < gacha_gold:
+            return f'10连抽卡需要{gacha_gold}金币，你的金币：{self._player_data[group_id][user_id]["gold"]}。'
         else:
-            russian_manager._player_data[group_id][user_id]["gold"] -= gacha_gold
+            self._player_data[group_id][user_id]["gold"] -= gacha_gold
             msg = '\n'
-            for i in range(10):
+            for _ in range(10):
                 props = random.randint(1,200)
                 if props in range(1,21):
-                    russian_manager._player_data[group_id][user_id]["props"].setdefault("四叶草标记",0)
-                    if russian_manager._player_data[group_id][user_id]["props"]["四叶草标记"] < 7:
-                        russian_manager._player_data[group_id][user_id]["props"]["四叶草标记"] += 1
+                    self._player_data[group_id][user_id]["props"].setdefault("四叶草标记",0)
+                    if self._player_data[group_id][user_id]["props"]["四叶草标记"] < 7:
+                        self._player_data[group_id][user_id]["props"]["四叶草标记"] += 1
                     msg += "『四叶草标记』 ☆☆☆\n"
                 elif props in range(21,31):
-                    russian_manager._player_data[group_id][user_id]["props"].setdefault("钻石会员卡",0)
-                    if russian_manager._player_data[group_id][user_id]["props"]["钻石会员卡"] < 7:
-                        russian_manager._player_data[group_id][user_id]["props"]["钻石会员卡"] += 1
+                    self._player_data[group_id][user_id]["props"].setdefault("钻石会员卡",0)
+                    if self._player_data[group_id][user_id]["props"]["钻石会员卡"] < 7:
+                        self._player_data[group_id][user_id]["props"]["钻石会员卡"] += 1
                     msg += "『钻石会员卡』 ☆☆☆☆\n"
                 elif props in range(31,41):
                     msg += "『高级空气』 ☆☆☆☆\n"
                 elif props in range(41,46):
-                    russian_manager._player_data[group_id][user_id]["props"].setdefault("20%结算补贴",0)
-                    if russian_manager._player_data[group_id][user_id]["props"]["20%结算补贴"] < 7:
-                        russian_manager._player_data[group_id][user_id]["props"]["20%结算补贴"] += 1
+                    self._player_data[group_id][user_id]["props"].setdefault("20%结算补贴",0)
+                    if self._player_data[group_id][user_id]["props"]["20%结算补贴"] < 7:
+                        self._player_data[group_id][user_id]["props"]["20%结算补贴"] += 1
                     msg += "『20%结算补贴』 ☆☆☆☆☆\n"
                 elif props in range(46,51):
-                    russian_manager._player_data[group_id][user_id]["props"].setdefault("20%额外奖励",0)
-                    if russian_manager._player_data[group_id][user_id]["props"]["20%额外奖励"] < 7:
-                        russian_manager._player_data[group_id][user_id]["props"]["20%额外奖励"] += 1
+                    self._player_data[group_id][user_id]["props"].setdefault("20%额外奖励",0)
+                    if self._player_data[group_id][user_id]["props"]["20%额外奖励"] < 7:
+                        self._player_data[group_id][user_id]["props"]["20%额外奖励"] += 1
                     msg += "『20%额外奖励』 ☆☆☆☆☆\n"
                 elif props in range(51,56):
                     msg += "『进口空气』 ☆☆☆☆☆\n"
@@ -1480,8 +1567,8 @@ class SingleManager:
                 elif props in range(61,81):
                     msg += "『优质空气』 ☆☆☆\n"
                 elif props == 100:
-                    russian_manager._player_data[group_id][user_id]["props"].setdefault("钻石",0)
-                    russian_manager._player_data[group_id][user_id]["props"]["钻石"] += 1
+                    self._player_data[group_id][user_id]["props"].setdefault("钻石",0)
+                    self._player_data[group_id][user_id]["props"]["钻石"] += 1
                     msg += "『钻石』 ☆☆☆☆☆☆\n"
                 elif props == 200:
                     msg += "『纯净空气』 ☆☆☆☆☆☆\n"
@@ -1490,12 +1577,12 @@ class SingleManager:
                     pass
             else:
                 msg = msg[:-1]
-                russian_manager.save()
+                self.save()
         return msg
 
 
 
-single_manager = SingleManager()
+russian_manager = GameManager()
 
 
 
@@ -1505,7 +1592,7 @@ class MarketManager:
         self._market_data = {}
         self.market_index = {}  # 市场指数
         file = russian_path / "data" / "russian" / "market_data.json"
-        self.market_index_file = file
+        self.file = file
         if not file.exists():
             old_file = Path(os.path.dirname(__file__)) / "market_data.json"
             if old_file.exists():
@@ -1572,7 +1659,7 @@ class MarketManager:
         """
         保存市场数据
         """
-        with open(self.market_index_file, "w", encoding="utf8") as f:
+        with open(self.file, "w", encoding="utf8") as f:
             json.dump(self._market_data, f, ensure_ascii=False, indent=4)
 
     def Stock_Exchange_save(self):
@@ -1652,72 +1739,72 @@ class MarketManager:
             return f"【{company_name}】未注册"
         else:
             lst = sorted(self.Stock_Exchange[company_name].items(),key = lambda x:x[1]["quote"])
-
+            i = 0
             count = 0
-            for i in range(len(lst)):
-                count += lst[i][1]["stock"]
-
-            for i in lst:
-                if i[0] == user_id:
-                    lst.remove(i)
-
+            while i < len(lst):
+                if lst[i][0] == user_id or lst[i][1]["stock"] == 0:
+                    lst.remove(lst[i])
+                else:
+                    count += lst[i][1]["stock"]
+                    i += 1
             if lst == []:
                 return f"市场上没有【{company_name}】"
             else:
                 stock = stock if count > stock else count
                 TL = {}
                 gold = 0.0
-                for i in range(len(lst)):
-                    _stock = lst[i][1]["stock"]
-                    _quote = lst[i][1]["quote"]
-                    _group_id = str(lst[i][1]["group_id"])
-
-                    _count = 0
-                    for j in range(_stock if _stock < stock else stock):
-                        _count += 1
-
+                for seller in lst:
+                    # 报价
+                    _quote = seller[1]["quote"]
+                    # 数量
+                    _stock = seller[1]["stock"]
+                    _count = _stock if _stock < stock else stock
                     stock -= _count
-
-                    TL.update({lst[i][0]:[_quote,_count,_group_id]})
-                    
+                    # 群组
+                    _group_id = seller[1]["group_id"]
+                    # 交易日志
+                    TL.update({seller[0]:[_quote,_count,_group_id]})
+                    # 统计金额
                     gold += _quote * _count
-
                 if gold > my_gold:
                     return (
-                        "金币不足\n"
+                        "金币不足：\n"
                         f'你的金币：{my_gold}'
                         f"需要金币：{int(gold)}"
                         )
                 else:
                     count = 0
-                    for i in range(len(lst)):
-                        unsettled = int (TL[lst[i][0]][0] * TL[lst[i][0]][1])
+                    for seller in lst:
+                        seller_group = TL[seller[0]][2]
+                        seller_id = seller[0]
+                        N = TL[seller_id][1]
+                        unsettled = int (TL[seller_id][0] * N)
                         
                         russian_manager._player_data[group_id][user_id]["gold"] -= unsettled
-                        russian_manager._player_data[TL[lst[i][0]][2]][lst[i][0]]["gold"] += unsettled
+                        russian_manager._player_data[seller_group][seller_id]["gold"] += unsettled
                         
                         russian_manager._player_data[group_id][user_id]["stock"]["value"] = self.value_update(group_id,user_id)
-                        russian_manager._player_data[TL[lst[i][0]][2]][lst[i][0]]["stock"]["value"] = self.value_update(TL[lst[i][0]][2],lst[i][0])
+                        russian_manager._player_data[seller_group][seller_id]["stock"]["value"] = self.value_update(seller_group,seller_id)
                         
                         russian_manager._player_data[group_id][user_id]["stock"].setdefault(company_name,0)
-                        russian_manager._player_data[group_id][user_id]["stock"][company_name] += TL[lst[i][0]][1]
+                        russian_manager._player_data[group_id][user_id]["stock"][company_name] += N
                    
-                        russian_manager._player_data[TL[lst[i][0]][2]][lst[i][0]]["stock"].setdefault(company_name,0)
-                        russian_manager._player_data[TL[lst[i][0]][2]][lst[i][0]]["stock"][company_name] -= TL[lst[i][0]][1]
+                        russian_manager._player_data[seller_group][seller_id]["stock"].setdefault(company_name,0)
+                        russian_manager._player_data[seller_group][seller_id]["stock"][company_name] -= N
                         
-                        self.Stock_Exchange[company_name][lst[i][0]]["stock"] -= TL[lst[i][0]][1]
-                        count += TL[lst[i][0]][1]
+                        self.Stock_Exchange[company_name][seller_id]["stock"] -= N
+                        count += N
                     else:
                         russian_manager.save()
                         self.Stock_Exchange_save()
-                        return (
-                            "交易成功！\n"
-                            "——————————————\n"
-                            f"【{company_name}】\n" 
-                            f"数量：{count}\n"
-                            f"价格：{round(gold/count,2)}\n"
-                            f"总计：{gold}"
-                            )
+                    return (
+                        "交易成功！\n"
+                        "——————————————\n"
+                        f"【{company_name}】\n" 
+                        f"数量：{count}\n"
+                        f"价格：{round(gold/count,2)}\n"
+                        f"总计：{gold}"
+                        )
 
     def Market_public(self, event: GroupMessageEvent,company_name: str):
         """
@@ -1759,7 +1846,7 @@ class MarketManager:
             if stock > 0:
                 value = 0.0
                 _gold = company["gold"] if  company["gold"] > company["float_gold"] else company["float_gold"]
-                for i in range(stock):
+                for _ in range(stock):
                     tmp = _gold/ 20000
                     tmp = 0.1 if tmp < 0.1 else tmp
                     _gold += tmp * 0.65
@@ -1782,10 +1869,7 @@ class MarketManager:
                         self._market_data[company_name]["gold"] += value
                         russian_manager._player_data[group_id][user_id]["gold"] -= int(value)
                         self._market_data[company_name]["group_gold"] = float(russian_manager.total_gold(str(self._market_data[company_name]["group_id"]),1000))
-                        gold = self._market_data[company_name]["gold"]
-                        group_gold = self._market_data[company_name]["group_gold"]
-                        float_gold = self._market_data[company_name]["float_gold"]
-                        self._market_data[company_name]["float_gold"] = float_gold * 0.4 + group_gold * 0.15 + gold * 0.3
+                        self._market_data[company_name]["float_gold"] += value * 0.65
                         russian_manager._player_data[group_id][user_id]["stock"]["value"] = self.value_update(group_id,user_id)
                         self.market_data_save()
                         russian_manager.save()
@@ -1822,7 +1906,7 @@ class MarketManager:
         else:
             value = 0.0
             _gold = company["float_gold"]
-            for i in range(stock):
+            for _ in range(stock):
                 tmp = float(_gold/ 20000)
                 _gold -= tmp * 0.65
                 value += tmp
@@ -1832,10 +1916,7 @@ class MarketManager:
                 self._market_data[company_name]["gold"] -= value
                 russian_manager._player_data[group_id][user_id]["gold"] += int(value * 0.998)
                 self._market_data[company_name]["group_gold"] = float(russian_manager.total_gold(str(self._market_data[company_name]["group_id"]),1000))
-                gold = self._market_data[company_name]["gold"]
-                group_gold = self._market_data[company_name]["group_gold"]
-                float_gold = self._market_data[company_name]["float_gold"]
-                self._market_data[company_name]["float_gold"] = float_gold * 0.4 + group_gold * 0.15 + gold * 0.3
+                self._market_data[company_name]["float_gold"] = _gold
                 russian_manager._player_data[group_id][user_id]["stock"]["value"] = self.value_update(group_id,user_id)
                 self.market_data_save()
                 russian_manager.save()
@@ -1863,23 +1944,30 @@ class MarketManager:
         """
         市场信息
         :param company_name:公司名，为空则是总览。
-        """ 
-        msg = ""
+        """
         if company_name in self.Stock_Exchange.keys():
             lst = sorted(self.Stock_Exchange[company_name].items(),key = lambda x:x[1]["quote"])
-            for i in range(len(lst) if len(lst) < 10 else 10):
+            i = 0
+            msg = ""
+            while i < (len(lst) if len(lst) < 10 else 10):
                 if lst[i][1]["stock"] > 0:
                     nickname = russian_manager._player_data[lst[i][1]["group_id"]][lst[i][0]]["nickname"]
                     msg += (
                         f'{nickname}\n'
                         f'单价：{lst[i][1]["quote"]} 数量：{lst[i][1]["stock"]}\n'
                         )
+                    i += 1
+                else:
+                    del lst[i]
+
             if msg:
                 msg = (f'【{company_name}】\n'"——————————————\n") + msg
                 msg = msg[:-1]
                 output = BytesIO()
                 Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
                 msg = MessageSegment.image(output)
+            else:
+                return f"【{company_name}】市场为空"
         else:
             lst = []
             for x in self._market_data.keys():
@@ -1889,28 +1977,28 @@ class MarketManager:
                 lst.sort(key = lambda x:x[1],reverse = True)
 
             msg_lst = []
-            n = len(lst)
-            if n:
-                for i in range(n):
+            if lst:
+                for x in lst:
                     price = (
-                        self._market_data[lst[i][0]]["gold"]
-                        if self._market_data[lst[i][0]]["gold"] > self._market_data[lst[i][0]]["float_gold"]
-                        else self._market_data[lst[i][0]]["float_gold"]
+                        self._market_data[x[0]]["gold"]
+                        if self._market_data[x[0]]["gold"] > self._market_data[x[0]]["float_gold"]
+                        else self._market_data[x[0]]["float_gold"]
                         )
                     msg_lst.append(
-                        f'【{lst[i][0]}】\n'
+                        f'【{x[0]}】\n'
                         "——————————————\n"
-                        f'固定资产：{round(self._market_data[lst[i][0]]["gold"], 2)} 金币\n'
-                        f'市场流动：{int(lst[i][1])} 金币\n'
+                        f'固定资产：{round(self._market_data[x[0]]["gold"], 2)} 金币\n'
+                        f'市场流动：{int(x[1])} 金币\n'
                         f'发行价格：{round(price/20000,2)} 金币\n'
-                        f'结算价格：{round(self._market_data[lst[i][0]]["float_gold"] / 20000, 2)} 金币\n'
-                        f'剩余数量：{self._market_data[lst[i][0]]["stock"]} 株\n'
+                        f'结算价格：{round(self._market_data[x[0]]["float_gold"] / 20000, 2)} 金币\n'
+                        f'剩余数量：{self._market_data[x[0]]["stock"]} 株\n'
                         "——————————————"
                         )
                 else:
                     if market_info_chain == False or isinstance(event, PrivateMessageEvent):
-                        for i in range(n):
-                            msg += msg_lst[i] + "\n"
+                        msg = ""
+                        for x in msg_lst:
+                            msg += x + "\n"
                         else:
                             msg = msg[:-1]
                             if market_info_type == "image":
@@ -1918,13 +2006,13 @@ class MarketManager:
                                 Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
                                 msg = MessageSegment.image(output)
                             else:
-                                msg = msg.replace("——————————————", "----------")
+                                pass
                     else:
                         msg = []
                         if market_info_type == "image" :
-                            for i in range(n):
+                            for x in msg_lst:
                                 output = BytesIO()
-                                Text2Image.from_text(msg_lst[i],50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
+                                Text2Image.from_text(x,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
                                 msg.append(
                                     {
                                         "type": "node",
@@ -1936,14 +2024,14 @@ class MarketManager:
                                         }
                                     )
                         else:
-                            for i in range(n):
+                            for x in msg_lst:
                                 msg.append(
                                     {
                                         "type": "node",
                                         "data": {
                                             "name": f"{bot_name}",
                                             "uin": str(event.self_id),
-                                            "content": msg_lst[i]
+                                            "content": x
                                             }
                                         }
                                     )
@@ -1951,11 +2039,10 @@ class MarketManager:
                 msg = "市场不存在..."
         return msg
 
-    async def Market_info_pro(self, event):
+    def Market_info_pro(self, event):
         """
         市场详细信息
         """
-
         if self.info_temp[1] == 1:
             return self.info_temp[0]
         else:
@@ -1968,11 +2055,11 @@ class MarketManager:
 
             if lst:
                 msg = []
-                for i in range(len(lst)):
+                for x in lst:
                     price = (
-                        self._market_data[lst[i][0]]["gold"]
-                        if self._market_data[lst[i][0]]["gold"] > self._market_data[lst[i][0]]["float_gold"]
-                        else self._market_data[lst[i][0]]["float_gold"]
+                        self._market_data[x[0]]["gold"]
+                        if self._market_data[x[0]]["gold"] > self._market_data[x[0]]["float_gold"]
+                        else self._market_data[x[0]]["float_gold"]
                         )
                     msg.append(
                         {
@@ -1981,13 +2068,13 @@ class MarketManager:
                                 "name": f"{bot_name}",
                                 "uin": str(event.self_id),
                                 "content": (
-                                    f'【{lst[i][0]}】\n'
+                                    f'【{x[0]}】\n'
                                     "——————————————\n"
-                                    f'固定资产：{round(self._market_data[lst[i][0]]["gold"], 2)} 金币\n'
-                                    f'市场流动：{int(lst[i][1])} 金币\n'
+                                    f'固定资产：{round(self._market_data[x[0]]["gold"], 2)} 金币\n'
+                                    f'市场流动：{int(x[1])} 金币\n'
                                     f'发行价格：{round(price/20000,2)} 金币\n'
-                                    f'结算价格：{round(self._market_data[lst[i][0]]["float_gold"] / 20000, 2)} 金币\n'
-                                    f'剩余数量：{self._market_data[lst[i][0]]["stock"]} 株\n'
+                                    f'结算价格：{round(self._market_data[x[0]]["float_gold"] / 20000, 2)} 金币\n'
+                                    f'剩余数量：{self._market_data[x[0]]["stock"]} 株\n'
                                     "——————————————"
                                     ) 
                                 }
@@ -1999,7 +2086,7 @@ class MarketManager:
                             "data": {
                                 "name": f"{bot_name}",
                                 "uin": str(event.self_id),
-                                "content": MessageSegment.image(await market_linechart((32,9), self.market_history[lst[i][0]], lst[i][0]))
+                                "content": MessageSegment.image(market_linechart((32,9), self.market_history[x[0]], x[0]))
                                 }
                             }
                         )
@@ -2009,7 +2096,7 @@ class MarketManager:
                             "data": {
                                 "name": f"{bot_name}",
                                 "uin": str(event.self_id),
-                                "content": MessageSegment.image(await market_candlestick((32,9), 6, self.market_history[lst[i][0]], lst[i][0]))
+                                "content": MessageSegment.image(market_candlestick((32,9), 6, self.market_history[x[0]], x[0]))
                                 }
                             }
                         )
@@ -2025,13 +2112,20 @@ class MarketManager:
         公司信息
         :param company_name:公司名。
         """ 
-        msg = ""
         if company_name in self.Stock_Exchange.keys():
             lst = sorted(self.Stock_Exchange[company_name].items(),key = lambda x:x[1]["quote"])
-            for i in range(len(lst) if len(lst) < 10 else 10):
+            i = 0
+            msg = ""
+            while i < (len(lst) if len(lst) < 10 else 10):
                 if lst[i][1]["stock"] > 0:
                     nickname = russian_manager._player_data[lst[i][1]["group_id"]][lst[i][0]]["nickname"]
-                    msg += f'{nickname}\n单价：{lst[i][1]["quote"]} 数量：{lst[i][1]["stock"]}\n'
+                    msg += (
+                        f'{nickname}\n'
+                        f'单价：{lst[i][1]["quote"]} 数量：{lst[i][1]["stock"]}\n'
+                        )
+                    i += 1
+                else:
+                    del lst[i]
 
             group_id = self._market_data[company_name]["group_id"]
             group_id = str(group_id)
@@ -2057,6 +2151,8 @@ class MarketManager:
                 "简介：\n"f'{self._market_data[company_name]["intro"]}'
                 )
             return info
+        else:
+            return None
 
     def update_intro(self,company_name:str,intro:str):
         """
@@ -2077,8 +2173,10 @@ class MarketManager:
         stock_data = russian_manager._player_data[group_id][user_id]["stock"]
         company_name = self._market_data.get(group_id,{"company_name": "value"})["company_name"]
         for i in stock_data.keys():
-            if not i in ["value",company_name]:
-                value += stock_data[i] * self._market_data[i]["gold"] / 20000
+            if  i in ["value",company_name]:
+                continue
+            else:
+                value += stock_data[i] * self._market_data[i]["float_gold"] / 20000
         return value
 
     def company_update(self,group_id:str):
@@ -2119,6 +2217,16 @@ class MarketManager:
         while len(self.market_history[company_name]) > 1200:
             del self.market_history[company_name][0]
 
+    def reset_market_index(self):
+        """
+        市场指数更新
+        """
+        for group_id in russian_manager._player_data.keys():
+            if group_id in market_manager._market_data.keys():
+                company_name = self._market_data[group_id]["company_name"]
+                self.market_index[company_name] = random.uniform(-0.5, 0.1)
+                logger.info(f'【{company_name}】市场指数更新为 {self.market_index.get(company_name,0)}')
+
     def intergroup_transfer(self, event, company_name, gold) -> str:
         """
         跨群转移金币到自己的账户
